@@ -131,7 +131,3 @@ def plot3d(lista_vetores,lista_cores,lista_limites):
                       length=1, normalize=False, color=lista_cores[i])
 
     plt.show()
-
-x=(0,0,2,2)
-w=(-1,-1,1,1)
-print(isequivalent2d([x,w]))
\ No newline at end of file
